OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Відсутній пароль ключа відновлення",
    "Please repeat the recovery key password" : "Введіть ще раз пароль для ключа відновлення",
    "Repeated recovery key password does not match the provided recovery key password" : "Введені паролі ключа відновлення не співпадають",
    "Recovery key successfully enabled" : "Ключ відновлення підключено",
    "Could not enable recovery key. Please check your recovery key password!" : "Не вдалося підключити ключ відновлення. Будь ласка, перевірте пароль свого ключа відновлення!",
    "Recovery key successfully disabled" : "Ключ відновлення відключено",
    "Could not disable recovery key. Please check your recovery key password!" : "Не вдалося відключити ключ відновлення. Будь ласка, перевірте пароль ключа відновлення!",
    "Missing parameters" : "Відсутні параметри",
    "Please provide the old recovery password" : "Будь ласка, введіть старий пароль відновлення",
    "Please provide a new recovery password" : "Будь ласка, введіть новий пароль відновлення",
    "Please repeat the new recovery password" : "Будь ласка, введіть новий пароль відновлення ще раз",
    "Password successfully changed." : "Пароль змінено.",
    "Could not change the password. Maybe the old password was not correct." : "Не вдалося змінити пароль. Можливо ви неправильно ввели старий пароль.",
    "Recovery Key disabled" : "Ключ відновлення відключений",
    "Recovery Key enabled" : "Відновлення ключа увімкнено",
    "Could not enable the recovery key, please try again or contact your administrator" : "Не вдалося підключити ключ відновлення, будь ласка, перевірте пароль ключа відновлення!",
    "Could not update the private key password." : "Не вдалося оновити пароль секретного ключа.",
    "The old password was not correct, please try again." : "Старий пароль введено не вірно, спробуйте ще раз.",
    "The current log-in password was not correct, please try again." : "Невірний пароль входу, будь ласка, спробуйте ще раз.",
    "Private key password successfully updated." : "Пароль секретного ключа оновлено.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Недійсний закритий ключ для програми шифрування. Щоб відновити доступ до зашифрованих файлів, оновіть пароль приватного ключа в особистих налаштуваннях.",
    "Encryption app is enabled and ready" : "Програма для шифрування ввімкнена та готова",
    "Bad Signature" : "Погана сиґнатура",
    "Missing Signature" : "Відсутній підпис",
    "one-time password for server-side-encryption" : "одноразовий пароль для шифрування на сервері",
    "Default encryption module" : "Типовий модуль шифрування",
    "Default encryption module for server-side encryption" : "Типовий модуль шифрування для шифрування на стороні сервера",
    "The share will expire on %s." : "Спільний доступ закінчиться %s.",
    "Cheers!" : "Будьмо!",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Програму для шифрування ввімкнено, але ваші ключі не ініціалізовано. Будь ласка, вийдіть із системи та увійдіть знову",
    "Encrypt the home storage" : "Зашифрувати домашню теку",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Увімкнення цього параметра шифрує всі файли, що зберігаються в основній пам’яті, інакше будуть зашифровані лише файли на зовнішній пам’яті",
    "Enable recovery key" : "Увімкнути ключ відновлення",
    "Disable recovery key" : "Вимкнути ключ відновлення",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Ключ відновлення — це додатковий ключ шифрування, який використовується для шифрування файлів. Це дозволяє відновити файли користувача, якщо користувач забув свій пароль.",
    "Recovery key password" : "Пароль ключа відновлення",
    "Repeat recovery key password" : "Повторіть пароль ключа відновлення",
    "Change recovery key password:" : "Змінити пароль ключа відновлення:",
    "Old recovery key password" : "Старий пароль ключа відновлення",
    "New recovery key password" : "Новий пароль ключа відновлення",
    "Repeat new recovery key password" : "Повторіть новий пароль ключа відновлення",
    "Change Password" : "Змінити Пароль",
    "Basic encryption module" : "Основний модуль шифрування",
    "Your private key password no longer matches your log-in password." : "Пароль вашого закритого ключа більше не відповідає паролю від вашого облікового запису.",
    "Set your old private key password to your current log-in password:" : "Замініть старий пароль від закритого ключа на новий пароль входу:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Якщо ви не пам'ятаєте ваш старий пароль, ви можете звернутися до адміністратора щоб його відновити.",
    "Old log-in password" : "Старий пароль входу",
    "Current log-in password" : "Поточний пароль входу",
    "Update Private Key Password" : "Оновити пароль для закритого ключа",
    "Enable password recovery:" : "Ввімкнути відновлення паролю:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Включення цієї опції дозволить вам отримати доступ до своїх зашифрованих файлів у випадку втрати паролю",
    "Enabled" : "Увімкнено",
    "Disabled" : "Вимкнено",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Привіт, <br> <br> адміністратор увімкнув шифрування на стороні сервера. Ваші файли були зашифровані за допомогою <strong>%s</strong> пароля. <br><br>Увійдіть у веб-інтерфейс, перейдіть до розділу «базовий модуль шифрування» ваших особистих налаштувань і оновіть пароль шифрування, ввівши цей пароль у поле «старий пароль для входу» та свій поточний логін-пароль.<br><br>"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
